@@ -1,7 +1,7 @@
 #!/bin/bash
 
 # This script creates light curves and other related
-# products by using Munipack data for 0716
+# products by using Munipack data for 0716+71
 #
 # See detailed description in lctut.html
 
@@ -27,7 +27,7 @@ munipack phcorr -dark d120.fits -flat f_R.fits 0716_*R.fits
 # grow, aperture photometry and star detection
 munipack find -f 3 0716_*.fits
 munipack aphot 0716_*.fits
-#munipack gphot 0716_*.fits
+munipack gphot 0716_*.fits
 
 # astrometry calibration
 munipack cone -c UCAC5 -r 0.2 -- 110.5 71.3
@@ -45,7 +45,7 @@ for FILTER in V R; do
   # manual
   for A in 0716_*${FILTER}.fits; do
     munipack phcal -C 1 --photsys-ref Johnson -f ${FILTER} \
-        -O --mask '\!\1_mancal.\2' $A;
+        --saper 4 -O --mask '\!\1_mancal.\2' $A;
   done
 
   # mancal, aperture 7, extinction
@@ -79,9 +79,10 @@ for FILTER in V R; do
   for A in 0716_*${FILTER}.fits; do
       munipack phcal \
         --photsys-ref Johnson --area 0.3 \
-        -f ${FILTER} --col-mag ${FILTER} --col-magerr ${FILTER}ERR  \
+        -f ${FILTER} --col-mag ${FILTER}mag --col-magerr e_${FILTER}mag  \
         -c 0716+71.fits \
-        -O --mask '\!\1_catcal.\2' \
+        --saper 4 \
+	-O --mask '\!\1_catcal.\2' \
         $A;
   done
 
@@ -90,6 +91,7 @@ for FILTER in V R; do
       munipack phcal \
         --photsys-ref Johnson --area 0.3 \
         -f ${FILTER}  \
+	--saper 4 \
         -r 0716_035${FILTER}_catcal.fits -O --mask '\!\1_refcal.\2' $A;
   done
 
@@ -99,6 +101,7 @@ for FILTER in V R; do
         --photsys-ref Johnson --area 0.3 --col-ra RAJ2000 --col-dec DEJ2000 \
         -f ${FILTER} --col-mag ${FILTER}mag --col-magerr e_${FILTER}mag  \
         -c cone_Johnson.fits \
+	--saper 4 \
         -O --mask '\!\1_ucacal.\2' \
         $A;
   done
@@ -161,7 +164,7 @@ set xlabel "JD - 2453409"
 set yrange[14.8:13.5]
 set term svg dynamic
 set output 'lc0716_V.svg'
-plot 'mancal_V' u (\$1-2453409):(\$2-\$4+11.8) t "diff(0716+71 - A) + 11.8", 'catcal_V' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, 'refcal_V' u (\$1-2453409):2 t "frame" ls 1 lc 3, 'ucacal_V' u (\$1-2453409):(\$2+0.1) t "UCAC5 + 0.2" ls 1 lc 4
+plot 'mancal_V' u (\$1-2453409):(\$2-\$4+11.8) t "diff(0716+71 - A) + 11.8", 'catcal_V' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, 'refcal_V' u (\$1-2453409):2 t "frame" ls 1 lc 3, 'ucacal_V' u (\$1-2453409):(\$2+0.1) t "UCAC4 + 0.2" ls 1 lc 4
 EOF
 
 
@@ -173,7 +176,7 @@ set xlabel "JD - 2453409"
 set yrange[11.9:11.2]
 set term svg dynamic
 set output 'comp0716_V.svg'
-plot 'mancal_V' u (\$1-2453409):(\$4-\$6+12.65) t "diff(A-B)+12.65", 'catcal_V' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, 'refcal_V' u (\$1-2453409):4 t "frame" ls 1 lc 3, 'ucacal_V' u (\$1-2453409):(\$4+0.1) t "UCAC5 + 0.2" ls 1 lc 4
+plot 'mancal_V' u (\$1-2453409):(\$4-\$6+12.65) t "diff(A-B)+12.65", 'catcal_V' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, 'refcal_V' u (\$1-2453409):4 t "frame" ls 1 lc 3, 'ucacal_V' u (\$1-2453409):(\$4+0.1) t "UCAC4 + 0.2" ls 1 lc 4
 EOF
 
 # plots, R filter
@@ -185,7 +188,7 @@ set xlabel "JD - 2453409"
 set yrange[14.5:13.0]
 set term svg dynamic
 set output 'lc0716_R.svg'
-plot 'mancal_R' u (\$1-2453409):(\$2-\$4+11.7) t "diff(0716+71 - A) + 11.7", 'catcal_R' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, 'refcal_R' u (\$1-2453409):2 t "frame" ls 1 lc 3, 'ucacal_R' u (\$1-2453409):(\$2+0.1) t "UCAC5 + 0.2" ls 1 lc 4
+plot 'mancal_R' u (\$1-2453409):(\$2-\$4+11.7) t "diff(0716+71 - A) + 11.7", 'catcal_R' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, 'refcal_R' u (\$1-2453409):2 t "frame" ls 1 lc 3, 'ucacal_R' u (\$1-2453409):(\$2+0.1) t "UCAC4 + 0.2" ls 1 lc 4
 EOF
 
 
@@ -197,35 +200,11 @@ set xlabel "JD - 2453409"
 set yrange[11.8:10.8]
 set term svg dynamic
 set output 'comp0716_R.svg'
-plot 'mancal_R' u (\$1-2453409):(\$4-\$6+12.5) t "diff(A-B+12.5)", 'catcal_R' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, 'refcal_R' u (\$1-2453409):4 t "frame" ls 1 lc 3, 'ucacal_R' u (\$1-2453409):(\$4+0.1) t "UCAC5 + 0.2" ls 1 lc 4
+plot 'mancal_R' u (\$1-2453409):(\$4-\$6+12.5) t "diff(A-B+12.5)", 'catcal_R' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, 'refcal_R' u (\$1-2453409):4 t "frame" ls 1 lc 3, 'ucacal_R' u (\$1-2453409):(\$4+0.1) t "UCAC4 + 0.2" ls 1 lc 4
 EOF
 
 
 # extinction (list instrumental magnitudes)
-#gnuplot <<EOF
-#set key top right
-#set title "Extinction on 0716+71 field"
-#set ylabel "Instrumental magnitude in V filter"
-#set xlabel "airmass"
-#set xrange[1:1.8]
-#set yrange[16.6:16.2]
-#set term svg dynamic
-#set output 'ext_V.svg'
-#plot 'ext_V' u 2:6 t "total flux", 'ext7_V' u 2:6 t "flux in 7-th aperture" ls 1 lc 2
-#EOF
-#
-#gnuplot <<EOF
-#set key top right
-#set title "Extinction on 0716+71 field"
-#set ylabel "Instrumental magnitude in R filter"
-#set xlabel "airmass"
-#set xrange[1:1.8]
-#set yrange[17:16.5]
-#set term svg dynamic
-#set output 'ext_R.svg'
-#plot 'ext_R' u 2:6 t "total flux", 'ext7_R' u 2:6 t "flux in 7-th aperture" ls 1 lc 2
-#EOF
-
 gnuplot <<EOF
 set key top right
 set title "Extinction on 0716+71 field"
