@@ -3,7 +3,7 @@
   Munipack
 
 
-  Copyright © 2009-2016 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2017 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -22,10 +22,19 @@
 
 */
 
-#define EMAIL "Filip Hroch <hroch@physics.muni.cz>"
-#define COPYLEFT L"© 1997-2016 " EMAIL
+#include "../config.h"
+
+#define EMAIL PACKAGE_BUGREPORT
 #define XVERSION PACKAGE_VERSION
-#define DVERSION "\n  DEVELOPMENT VERSION (build: " __DATE__ ", " __TIME__ ")"
 #define INFOTEXT PACKAGE_NAME
+#define HOMEPAGE PACKAGE_URL
+
+#define COPYLEFT L"© 1997-2017 " EMAIL
+
+#ifdef DEVELBUILD
+#define DVERSION "\n  DEVELOPMENT VERSION (build: " DATEBUILD ")"
+#else
+#define DVERSION ""
+#endif
+
 #define INFOTEXTFULL "A general astronomical image processing software\n" DVERSION
-#define HOMEPAGE "http://munipack.physics.muni.cz/"
