@@ -2,7 +2,7 @@
 
   Munipack - command line parser
 
-  Copyright © 2010-16 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010-17 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -104,6 +104,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
 		 " aphot\t\tAperture photometry\n"
 		 " gphot\t\tGrowth-Curve photometry\n"
 		 " phcal\t\tPhotometry calibration\n"
+		 " artificial\tArtificial frames\n"
 		 " phfotran\tDetermine photometry system color transformation\n"
 		 " timeseries\tList arbitrary quantity to time-series\n"
 		 "\nLow Level Actions:\n"
@@ -200,7 +201,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
 
   else if( action == "ctrafo" ) {
 
-    AddUsageText("Usage: munipack "+action+" [options] file black(s),weight(s)]");
+    AddUsageText("Usage: munipack "+action+" [options] file black(s),weight(s)");
     AddUsageText("* Transform color frames between various color-spaces.");
 
     AddSwitch(wxEmptyString,"list","known colospaces");
@@ -421,6 +422,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddOption(wxEmptyString,"update-key","key=value[,comment] add/update keyword");
     AddOption(wxEmptyString,"remove-extensions","extname[,extname,..] remove extension(s)");
     AddSwitch(wxEmptyString,"shell","shell-friendly format for print of keywords");
+    AddSwitch(wxEmptyString,"value","only values of keywords are printed");
     AddSwitch(wxEmptyString,"dump","dump FITS to plain text");
     AddSwitch(wxEmptyString,"restore","restore FITS from plain text");
     COMMON_OPTIONS_MULTIPLE
@@ -515,6 +517,66 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddParam("file(s)",wxCMD_LINE_VAL_STRING,
   	     wxCMD_LINE_PARAM_MULTIPLE|wxCMD_LINE_PARAM_OPTIONAL);
   }
+
+  else if( action == "artificial" ) {
+
+    AddUsageText("Usage: munipack "+action+" [options] file(s)");
+    AddUsageText("* Photometrically realistic artificial frames.");
+
+    AddOption("","psf","PSF function: SEEING, MOFFAT, GAUSS");
+    AddOption("","spread","seeing spread method: FFT, RANDOM, AUTO");
+    AddOption("","hwhm","half width at half of maximum [pix]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","airy","radius of Airy spot [pix]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","beta","Moffat exponent",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","maglim","magnitude limit",wxCMD_LINE_VAL_NUMBER);
+    AddOption("","lc-model","light curve model: Cepheid,Algol,wave(default)");
+    AddOption("","lc-table","light curve model in the table");
+    AddOption("","lc-fourier","light curve model by Fourier coefficients");
+    AddOption("","lc-mag","mean magnitude of the variable object",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-amp","amplitude of the curve",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-jd0","reference Julian date for the light curve",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-per","period for the light curve [days]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-ra","variable object Right Ascension [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-dec","variable object Declination [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","back-level","background level [cts]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","back-noise","background noise [cts]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","back-grad-x","background gradient in x [cts/pix]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","back-grad-y","background gradient in y [cts/pix]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","area","area of input aperture [m2]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","diameter","diameter of input aperture [m]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","exptime","exposure time [s]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","qeff","quantum efficiency",wxCMD_LINE_VAL_DOUBLE);
+    AddSwitch("","atmosphere","apply atmosphere modelling: extinction, seeing");
+    AddOption("","extk","extinction coefficient",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","long","geographic longitude of station (-east)[deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lat","geographic latitude of station (+north)[deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","date","initial date as YYYY-MM-DD");
+    AddOption("","time","initial time as HH:MM:SS");
+    AddOption("","count","total number of generated files",wxCMD_LINE_VAL_NUMBER);
+    AddOption("","timestep","timestep in seconds",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("f","filter","photometry filter");
+
+    AddOption("c","cat","reference photometry catalogue");
+
+    AddOption("","fov","field of view [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"rcen","center of FOV in Right Ascension [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"dcen","center of FOV in Declination [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"scale","scale [deg/pix]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"angle","rotation angle [deg], clockwise positive",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","width","width of output [pix]",wxCMD_LINE_VAL_NUMBER);
+    AddOption("","height","height of output [pix]",wxCMD_LINE_VAL_NUMBER);
+    AddOption("","col-ra","Right Ascension column");
+    AddOption("","col-dec","Declination column");
+    AddOption("","col-pm-ra","Proper motion in Right Ascension column");
+    AddOption("","col-pm-dec","Proper motion in Declination column");
+    AddOption("","col-mag","Magnitude-like column");
+    AddOption("","photsys","photometry system");
+    AddOption("","phsystab","photometry systems definition table");
+    AddOption("","mask","mask for output files (artificial_???.fits)");
+    COMMON_OPTIONS_BITPIX
+  }
+
+
 }
 
 MuniCmdLineParser::~MuniCmdLineParser()
@@ -530,7 +592,7 @@ void MuniCmdLineParser::Usage() const
   wxString u(GetUsageString());
 
   // default Usage prints no actions, we are remove one and replace
-  // with acceptable form.
+  // with more suitable form.
   wxRegEx re("(Usage:.*[#]\n)(.*)");
   wxASSERT(re.IsValid());
   if( re.Matches(u) ) {
