@@ -1,9 +1,9 @@
-/* 
+/*
 
   VOTable parser
 
 
-  Copyright © 2010-2015 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010-2015, 2017 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -11,12 +11,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -25,6 +25,13 @@
 
   http://www.ivoa.net/Documents/VOTable/20091130/REC-VOTable-1.2.html
 
+
+  I've doubts about determination of coordinate frame. Vizier offers
+  a different structure for UCAC4 and UCAC5 catalogues. It means that
+  determination of epoch of catalogue coordinates cann't be assumed
+  as a simple parameter. Does it look as the maintainers proposed
+  another way of processing?
+
 */
 
 #include "votable.h"
@@ -40,7 +47,7 @@
 #include <wx/sstream.h>
 #include <wx/file.h>
 #include <wx/filename.h>
-#include <wx/filefn.h> 
+#include <wx/filefn.h>
 #include <wx/regex.h>
 #include <fitsio.h>
 #include <cmath>
@@ -179,7 +186,7 @@ VOGroup::VOGroup(const wxXmlNode *root)
       refs.push_back(node->GetNodeContent());
 
     node = node->GetNext();
-  }  
+  }
 }
 
 
@@ -192,12 +199,12 @@ VOTableData::VOTableData(const wxXmlNode *root): nrows(0)
 
   wxXmlNode *tr = root->GetChildren();
   while (tr) {
-    
+
     if( tr->GetName() == "TR" ) {
-      
+
       nrows++;
       rows.push_back(tr);
-      
+
       wxXmlNode *td = tr->GetChildren();
       while (td) {
 	elements.push_back(td->GetNodeContent());
@@ -221,7 +228,7 @@ VOData::VOData(const wxXmlNode *root)
 
   wxXmlNode *node = root->GetChildren();
   while (node) {
-    
+
     if( node->GetName() == "TABLEDATA" ) {
       tablenode = node;
       table = VOTableData(node);
@@ -416,7 +423,7 @@ bool VOTable::Parse()
       resources.push_back(VOResource(node));
 
     node = node->GetNext();
-  }  
+  }
 
   //  wxASSERT(resources.size() > 0);
   //  isok = resources.size() > 0;
@@ -424,8 +431,8 @@ bool VOTable::Parse()
 }
 
 void VOTable::SetProjection(const wxString& a) { proj_type = a;}
-void VOTable::SetProjectionCenter(double a,double d) 
-{ 
+void VOTable::SetProjectionCenter(double a,double d)
+{
   proj_alpha = a;
   proj_delta = d;
 }
@@ -438,16 +445,16 @@ void VOTable::SetDeltakey(const wxString& a) { delta_key = a; }
 
 wxString VOTable::GetDescription() const { return description; }
 
-double VOTable::GetEpoch() const 
+double VOTable::GetEpoch() const
 {
-  if( resources.size() > (size_t) index && resources[index].coosys.size() == 1 ) 
+  if( resources.size() > (size_t) index && resources[index].coosys.size() == 1 )
     return resources[index].coosys[0].GetEpoch();
-  else 
-    return 0;
+  else
+    return 2000.0;
 }
 
 
-int VOTable::RecordCount() const 
+int VOTable::RecordCount() const
 {
   wxASSERT(resources[index].tables.size() == 1);
   return resources[index].tables[0].RecordCount();
@@ -545,9 +552,9 @@ bool VOTable::Save(const wxString& filename, const wxString& backup, const wxStr
     return false;
 
   wxFFileOutputStream output(ffile);
-      
+
   //  wxFFileOutputStream output(filename.IsEmpty() ? wxFile::fd_stdout : filename);
-    
+
       //  wxFFileOutputStream o(filename);
   //  wxLogDebug("*****");
 
@@ -567,7 +574,7 @@ bool VOTable::Save(wxOutputStream& ostream, const wxString& type)
 
   else if( type == "SVG" )
     return SaveSVG(ostream);
-    
+
   else {
     wxLogFatalError("Type `"+type+"' unrecognized.");
     return false;
@@ -635,7 +642,7 @@ vector<wxString> VOTable::FitsTypes()
 	  tform.push_back(a+"A");
 	}
       }
-      else 	
+      else
 	tform.push_back("1A");
     }
     else if( datatype == "double" )
@@ -666,7 +673,7 @@ vector<wxString> VOTable::FitsTypes()
   }
   return tform;
 }
-  
+
 
 char **VOTable::GetArray(const vector<wxString>& vec)
 {
@@ -700,7 +707,7 @@ bool VOTable::SaveText(wxOutputStream& output)
   wxFFileOutputStream output(ffile);
   */
   wxTextOutputStream cout(output);
-  
+
   vector<wxString> fs = GetFields();
   for(vector<wxString>::const_iterator i = fs.begin(); i != fs.end(); ++i) {
     if( i != fs.begin() ) cout << "\t";
@@ -713,7 +720,7 @@ bool VOTable::SaveText(wxOutputStream& output)
   for(int n = 0; n < RecordCount(); n++) {
 
     vector<wxString> r = GetRecord(n);
-    
+
     for(vector<wxString>::const_iterator i = r.begin(); i != r.end(); ++i) {
       if( i != r.begin() ) cout << " \t";
       wxString a(*i);
@@ -734,7 +741,7 @@ bool VOTable::SaveCSV(wxOutputStream& output)
 
   //  wxFFileOutputStream output(file);
   wxTextOutputStream cout(output);
-  
+
   vector<wxString> fs = GetFields();
   for(vector<wxString>::const_iterator i = fs.begin(); i != fs.end(); ++i) {
     if( i != fs.begin() ) cout << ",";
@@ -747,14 +754,14 @@ bool VOTable::SaveCSV(wxOutputStream& output)
   for(int n = 0; n < RecordCount(); n++) {
 
     vector<wxString> r = GetRecord(n);
-    
+
     for(vector<wxString>::const_iterator i = r.begin(); i != r.end(); ++i) {
       if( i != r.begin() ) cout << ",";
       wxString a(*i);
       a.Replace("\n",""); a.Replace("\r","");
       cout << a;
     }
-    
+
     cout << endl;
   }
 
@@ -839,7 +846,7 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
 	  x[j] = 'T';
 	else if( c[j]== "F" || c[j]== "f" || c[j]== "0" )
 	  x[j] = 'F';
-	else { 
+	else {
 	  x[j] = ' ';
 	  if( c[j] != "" ) {
 	    wxLogError("Failed convert element `"+c[j]+"' at row=%d col="+fs[i]+
@@ -855,7 +862,7 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
       char *x = new char[n];
       for(size_t j = 0; j < n; j++) {
 	long t;
-	if( c[j].ToLong(&t) && (t == 0 || t == 1) ) 
+	if( c[j].ToLong(&t) && (t == 0 || t == 1) )
 	  x[j] = t;
 	else {
 	  x[j] = 0;
@@ -873,7 +880,7 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
       unsigned char *x = new unsigned char[n];
       for(size_t j = 0; j < n; j++) {
 	long t;
-	if(  c[j].ToLong(&t) && (0 <= t && t < 256) ) 
+	if(  c[j].ToLong(&t) && (0 <= t && t < 256) )
 	  x[j] = t;
 	else {
 	  x[j] = 0;
@@ -935,7 +942,7 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
 	    wxLogError("Failed convert element `"+c[j]+"' at row=%d col="+fs[i]+
 		       " to long.",(int)j);
 	  }
-	}	  
+	}
       }
       fits_write_col(file,TLONG,i+1,1,1,n,x,&status);
       delete[] x;
@@ -1050,7 +1057,7 @@ bool VOTable::SaveSVG(wxOutputStream& output)
   cout << "<svg xmlns=\"http://www.w3.org/2000/svg\">" << endl;
 
   // WARNING: only simple gnonomical projection is implemented
-  
+
   double c = xdec.size() > 0 ? cos(ToDouble(xdec[0])/57.3) : 1.0;
   for(size_t i = 0; i < xra.size(); i++) {
     double ra = ToDouble(xra[i]);
@@ -1063,7 +1070,7 @@ bool VOTable::SaveSVG(wxOutputStream& output)
     cout << "<circle cx=\"" << x << "\" cy=\"" << y
 	 << "\" r=\"" << r << "\"/>" << endl;
   }
-  
+
   cout << "</svg>" << endl;
   return true;
 }
@@ -1087,7 +1094,7 @@ bool VOTable::Sort(const wxString& key)
       break;
     }
   }
-  
+
   if( n == -1 )
     return false;
 
@@ -1101,11 +1108,11 @@ bool VOTable::Sort(const wxString& key)
     a.ToDouble(&x);
     d.push_back(make_pair(i-col.begin(),x));
   }
-  
+
   sort(d.begin(),d.end(),cmp);
-  
+
   /*
-  for(vector< pair<int,double> >::const_iterator i = d.begin(); i != d.end(); ++i) 
+  for(vector< pair<int,double> >::const_iterator i = d.begin(); i != d.end(); ++i)
   wxLogDebug("%d %f",i->first,i->second);
   */
 
@@ -1119,7 +1126,7 @@ bool VOTable::Sort(const wxString& key)
 				t->GetName(),t->GetContent(),
 				t->GetAttributes(),t->GetNext(),
 				t->GetLineNumber());
-      
+
   vector<wxXmlNode *> rows(resources[index].tables[0].data.table.rows);
 
   for(vector< pair<int,double> >::const_iterator i=d.begin(); i!=d.end(); ++i)
